@@ -1,5 +1,4 @@
 #!/bin/python
-import logging
 
 import requests
 from ocm_python_client.api.default_api import DefaultApi
@@ -8,8 +7,9 @@ from ocm_python_client.configuration import Configuration
 from ocm_python_client.exceptions import UnauthorizedException
 
 from ocm_python_wrapper.exceptions import AuthenticationError, EndpointAccessError
+from ocm_python_wrapper.logger import get_logger
 
-LOGGER = logging.getLogger(__name__)
+LOGGER = get_logger(__name__)
 
 
 class OCMPythonClient(ApiClient):
